﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using Shape_Mapper.Properties;

namespace Shape_Mapper
{
    public partial class MainForm : Form
    {
        public MainForm()
        {
            InitializeComponent();

            // Load settings
            nudGridDim.Value = Settings.Default.GridDim;
           // grid.VertexDimension = Settings.Default.GridDim;
        }

        protected override void OnClosing(CancelEventArgs e)
        {
            Settings.Default.GridDim =  grid.VertexDimension;
            base.OnClosing(e);
        }

        protected override void OnKeyDown(KeyEventArgs e)
        {
            base.OnKeyDown(e);

            if (e.KeyCode == Keys.Delete)
            {
                grid.DeleteNearestRefLine();
            }
        }

        private void nudGridDim_ValueChanged(object sender, EventArgs e)
        {
            grid.GridDimension = (int)nudGridDim.Value;
        }

        private string ShapeToDefiningCode(Point[] shape)
        {
            if (shape.Length == 0) return string.Empty;

            StringBuilder SB = new StringBuilder();
            // Add point array start
            SB.Append("PointF[] points = new PointF[]\r\n{\r\n");

            // Add points
            const string POINT_FORMAT = "new PointF({0}, {1}), ";

            foreach (Point pos in grid.Shape.GetPlotPoints(grid))
            {
                float xPercent = (float)Math.Round(pos.X / (double)grid.Width, 2);
                float yPercent = (float)Math.Round(pos.Y / (double)grid.Height, 2);
                string x = "rect.X + rect.Width * " + xPercent.ToString() + "f";
                string y = "rect.Y + rect.Height * " + yPercent.ToString() + "f";
                SB.Append(string.Format(POINT_FORMAT, x, y) + "\r\n");
            }

            SB.Remove(SB.Length - 4, 2);
            SB.Append("};");

            return SB.ToString();
        }

        private void grid_PointAdded(object sender, EventArgs e)
        {
            txtShapeCode.Text = ShapeToDefiningCode(grid.Shape.GetPlotPoints(grid));
        }

        private void btnClear_Click(object sender, EventArgs e)
        {
            grid.Clear();
        }

        private void btnSetBgImage_Click(object sender, EventArgs e)
        {
            using (OpenFileDialog dlgOpenFile = new OpenFileDialog())
            {
                dlgOpenFile.Filter = @"All Files|*.*";

                if (dlgOpenFile.ShowDialog() == DialogResult.OK)
                {
                    try
                    {
                        grid.BackgroundImage = Bitmap.FromFile(dlgOpenFile.FileName);
                    }
                    catch (Exception ex)
                    {
                        MessageBox.Show(ex.Message);
                    }
                }
            }
        }

        private void btnSaveShape_Click(object sender, EventArgs e)
        {
            using (SaveFileDialog dlgSaveFile = new SaveFileDialog())
            {
                dlgSaveFile.Filter = "Shape File|.shp";

                if (dlgSaveFile.ShowDialog() == DialogResult.OK)
                {
                    StringBuilder SB = new StringBuilder();

                    foreach (Point pos in grid.Shape.GetPlotPoints(grid))
                    {

                    }
                }
            }
        }
    }
}
