﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Drawing;
using System.Drawing.Drawing2D;

namespace Shape_Mapper
{
    class Shape
    {
        private List<Plot> _plots = new List<Plot>();
        private Pen _shapeLine = new Pen(Color.White, 3f);

        public Shape()
        {
            _shapeLine.LineJoin = LineJoin.Round;
            _shapeLine.EndCap = LineCap.Round;
            _shapeLine.StartCap = LineCap.Round;
        }

        public List<Plot> PlotList
        {
            get { return _plots; }
        }

        public Point[] GetPlotPoints(Grid grid)
        {
                List<Point> points = new List<Point>();

                foreach (Plot plot in _plots)
                {
                    points.Add(plot.GetLocation(grid));
                }

                return points.ToArray();
        }

        public void DrawShapeOutline(Grid grid)
        {
            Point[] points = GetPlotPoints(grid);
            grid.BackBuffer.DrawPolygon(_shapeLine, points.ToArray());
        }

        public void DrawShapeNodes(Grid grid)
        {
            if (_plots.Count > 0)
            {
                // Draw start node
                Point startLocation = _plots[0].GetLocation(grid);
                float x = startLocation.X - grid.VertexDimension / 2f; // center it
                float y = startLocation.Y - grid.VertexDimension / 2f;
                grid.BackBuffer.FillEllipse(Brushes.LightGreen, x, y, grid.VertexDimension, grid.VertexDimension);

                if (_plots.Count > 1)
                {
                    // Draw end node
                    Point endLocation = _plots[_plots.Count - 1].GetLocation(grid);
                    x = endLocation.X - grid.VertexDimension / 2f; // center it
                    y = endLocation.Y - grid.VertexDimension / 2f;
                    grid.BackBuffer.FillEllipse(Brushes.LightCoral, x, y, grid.VertexDimension, grid.VertexDimension);
                }
            }
        }
    }
}
